django\_sorcery.views package
=============================

.. automodule:: django_sorcery.views
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   django_sorcery.views.base
   django_sorcery.views.detail
   django_sorcery.views.edit
   django_sorcery.views.list

